@@ -24,7 +24,7 @@ ObjectiveTuning = R6Class("ObjectiveTuning",
     #' @field learner ([mlr3::Learner]).
     learner = NULL,
 
-    #' @field resampling ([mlr3::Resampling]).
+     #' @field resampling ([mlr3::Resampling]).
     resampling = NULL,
 
     #' @field measures (list of [mlr3::Measure]).
@@ -41,54 +41,59 @@ ObjectiveTuning = R6Class("ObjectiveTuning",
 
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(task, learner, resampling, measures,
-      check_values = TRUE, store_benchmark_result = TRUE,
+    initialize = function(task, learner, resampling, measures, check_values = TRUE, store_benchmark_result = TRUE,
       store_models = FALSE) {
 
       self$task = assert_task(as_task(task, clone = TRUE))
-      self$learner = assert_learner(as_learner(learner, clone = TRUE))
-      self$resampling = assert_resampling(as_resampling(
-        resampling,
-        clone = TRUE))
+      self$learner = assert_learner(as_learner(learner, clone = TRUE))      
       self$measures = assert_measures(as_measures(measures, clone = TRUE),
         task = self$task, learner = self$learner)
       self$store_benchmark_result = assert_logical(store_benchmark_result)
       self$store_models = assert_logical(store_models)
-      if (!resampling$is_instantiated) {
-        self$resampling$instantiate(self$task)
-      }
 
       codomain = ParamSet$new(map(self$measures, function(s) {
         ParamDbl$new(id = s$id, tags = ifelse(s$minimize, "minimize", "maximize"))
       }))
 
-      super$initialize(id = sprintf("%s_on_%s", self$learner$id, self$task$id), 
-        domain = self$learner$param_set, codomain = codomain, check_values = check_values)
+      super$initialize(id = sprintf("%s_on_%s", self$learner$id, self$task$id), domain = self$learner$param_set, 
+        codomain = codomain, constants = ps(resampling = p_uty()), check_values = check_values)
+
+      # set resamplings in constants
+      resampling = assert_resampling(as_resampling(resampling, clone = TRUE))
+      if (!resampling$is_instantiated) resampling$instantiate(task)
+      self$resampling = resampling
+      self$constants$values$resampling = list(resampling)
     }
   ),
 
   private = list(
-    .eval_many = function(xss) {
+    .eval_many = function(xss, resampling) {
       learners = map(xss, function(x) {
         learner = self$learner$clone(deep = TRUE)
         learner$param_set$values = insert_named(learner$param_set$values, x)
         return(learner)
       })
 
-      design = benchmark_grid(self$task, learners, self$resampling)
+      design = data.table(task = list(self$task), learner = learners, resampling = resampling)
       bmr = benchmark(design, store_models = self$store_models)
       aggr = bmr$aggregate(self$measures)
       y = map_chr(self$measures, "id")
 
+      # add runtime
+      time = map_dbl(bmr$resample_results$resample_result, function(rr) {
+        sum(map_dbl(rr$learners, function(l) sum(l$timings)))
+      })
+      aggr[, "runtime_learners" := time]
+
       if (self$store_benchmark_result) {
         if (is.null(self$archive$benchmark_result)) {
           self$archive$benchmark_result = bmr
         } else {
           self$archive$benchmark_result$combine(bmr)
         }
-        cbind(aggr[, y, with = FALSE], uhash = bmr$uhashes)
+        cbind(aggr[, c(y, "runtime_learners"), with = FALSE], uhash = bmr$uhashes)
       } else {
-        aggr[, y, with = FALSE]
+        aggr[, c(y, "runtime_learners"), with = FALSE]
       }
     }
   )
