@@ -116,3 +116,53 @@ test_that("TuneToken and result_learner_param_vals works", {
   expect_equal(instance$result_learner_param_vals[[1]]$xval, 0)
   expect_equal(instance$result_learner_param_vals[[1]]$cp, 0.1)
 })
+
+test_that("TuningInstanceMultiCrit and empty search space works", {
+  # xval constant
+  instance = tune(
+    method = "random_search",
+    task = tsk("pima"),
+    learner = lrn("classif.rpart"),
+    resampling = rsmp("cv", folds = 3),
+    measure = msrs(c("classif.ce", "classif.acc")),
+    term_evals = 10,
+    batch_size = 5
+  )
+
+  expect_data_table(instance$result)
+  expect_equal(instance$result$learner_param_vals[[1]], list(xval = 0))
+  expect_equal(instance$result$x_domain[[1]], list())
+
+  # xval and cp constant
+  instance = tune(
+    method = "random_search",
+    task = tsk("pima"),
+    learner = lrn("classif.rpart", xval = 0, cp = 0.1),
+    resampling = rsmp("cv", folds = 3),
+    measure = msrs(c("classif.ce", "classif.acc")),
+    term_evals = 10,
+    batch_size = 5
+  )
+
+  expect_data_table(instance$result)
+  expect_equal(instance$result$learner_param_vals[[1]], list(xval = 0, cp = 0.1))
+  expect_equal(instance$result$x_domain[[1]], list())
+
+  # no constant
+  learner = lrn("classif.rpart")
+  learner$param_set$values$xval = NULL
+
+  instance = tune(
+    method = "random_search",
+    task = tsk("pima"),
+    learner = learner,
+    resampling = rsmp("cv", folds = 3),
+    measure = msrs(c("classif.ce", "classif.acc")),
+    term_evals = 10,
+    batch_size = 5
+  )
+
+  expect_data_table(instance$result)
+  expect_equal(instance$result$learner_param_vals[[1]], list())
+  expect_equal(instance$result$x_domain[[1]], list())
+})
