@@ -224,3 +224,40 @@ test_that("TuneToken and result_learner_param_vals works", {
   expect_equal(instance$result_learner_param_vals$xval, 0)
   expect_equal(instance$result_learner_param_vals$cp, 0.1)
 })
+
+
+test_that("TuningInstanceSingleCrit and empty search space works", {
+
+  # xval constant
+  instance = tune(
+    method = "random_search",
+    task = tsk("pima"),
+    learner = lrn("classif.rpart"),
+    resampling = rsmp("cv", folds = 3),
+    measure = msr("classif.ce"),
+    term_evals = 10,
+    batch_size = 5
+  )
+
+  expect_data_table(instance$result)
+  expect_equal(instance$result$learner_param_vals, list(list(xval = 0)))
+  expect_equal(instance$result$x_domain, list(list()))
+
+  # no constant
+  learner = lrn("classif.rpart")
+  learner$param_set$values$xval = NULL
+
+  instance = tune(
+    method = "random_search",
+    task = tsk("pima"),
+    learner = learner,
+    resampling = rsmp("cv", folds = 3),
+    measure = msr("classif.ce"),
+    term_evals = 10,
+    batch_size = 5
+  )
+
+  expect_data_table(instance$result)
+  expect_equal(instance$result$learner_param_vals, list(list()))
+  expect_equal(instance$result$x_domain, list(list()))
+})
