@@ -15,7 +15,7 @@ test_that("simple exp trafo works", {
   expect_equal(inst$result_x_search_space, data.table(cp = -7))
   expect_equal(inst$result_learner_param_vals, list(xval = 0, cp = 2^-7))
   expect_equal(inst$result_y, c(dummy.cp.classif = 2^-7))
-  a = inst$archive$data()
+  a = inst$archive$data
   expect_equal(a$x_domain, list(list(cp = 2^-7), list(cp = 2^-3)))
 })
 
@@ -39,7 +39,7 @@ test_that("trafo where param names change", {
   expect_equal(inst$result_x_search_space, data.table(foo = "a"))
   expect_equal(inst$result_learner_param_vals, list(xval = 0, cp = 0.11))
   expect_equal(inst$result_y, c(dummy.cp.classif = 0.11))
-  a = inst$archive$data()
+  a = inst$archive$data
   expect_setequal(unlist(a$x_domain), c(0.11, 0.22)) # expect_equal not working since TunerGridSearch shuffles points
 })
 
